<h1>Tiquations 2.0</h1>

<h2>Welcome</h2>
<p>Tiquations is an Open-Source Python package that is aimed at giving mathematicians and scientists easy access to important equations that they may use often. It was made in python 3.7 and should work on all versions higher than 3.0.</p>
<h2>Documentation</h2>
<p>There is an official tiquations website now thanks to creme from Discord! Head over to [tiquations.com](https://www.tiquations.com) to check it out!</p>

<h2>Help commands</h2>
<ul>
<li>tiquations.help()</li>
<li>tiquations.changelog()</li>
</ul>

<h2>Equations</h2>
<ul>
<li>Quadratic equation</li>
<li>Mathematical sequence equations</li>
<li>Cosine Rules for angles and sides</li>
<li>Distance/Speed/Time</li>
<li>Force/Mass/Acceleration</li>
<li>Weight/Mass/Gravitational field strength</li>
<li>Circle area/diameter/circumference</li>
<li>Delta Velocity/Time taken/Acceleration</li>
<li>Force/Area/Pressure</li>
<li>Cylinder Volume/Surface Area</li>
<li>Trapezoid Area/Height/Surface Area</li>
<li>Pythagoras' Theorum</li>
<li>Energy/Charge/Potential difference</li>
<li>Power/Current/Potential difference</li>
<li>Power/Energy/Time</li>
<li>Orbital speed/Radius/Time taken</li>
<li>Cosine rule for sides and angles</li>
<li>Energy/Mass/Light speed</li>
<li>Schwarzschild radius</li>
<li>Sphere Mass/Density/Radius/Volume</li>
<li>Cube Volume</li>
<li>Cone Volume</li>
<li>Pyramid Volume</li>
<li>Wave frequency using time</li>
<li>Wave frequency/wave length/ wave speed</li>
<li>Refractive Index/Angle of incidence/Angle of refraction</li>
<li>Velocity/Kinetic Energy/Mass</li>
<li>Gravitational Potential Energy/Mass/Gravity/Height</li>
<li>Friction coefficient/Friction force/Normal force</li>
<li>Friction coefficient/Gravity/Acceleration</li>
<li>Coefficient/Normal/Friction</li>
<li>Focal point/Radius</li>
<li>Focal point/Distance of image/Distance of object</li>
<li>Mirror magnification/Height of image/ Distance of object</li>
<li>Mirror magnification/Distance of image/Distance of object</li>
<li>Photon energy</li>
<li>Moment/Force/Distance From Pivot</li>
<li>Fringe Spacing</li>
<li>Wave Period/Frequency/Wavelength/Velocity</li>
</ul>

<h2>Conversion</h2>
<ul>
<li>Kelvin/Fahrenheit/Celsius</li>
<li>bits/bytes/kilobytes/megabytes/gigabytes/terabytes/petabytes</li>
<li>miles/kilometers</li>
</ul>
